pub enum Traversal {
OutOfOrder {
expected_offset: u64,
actual_offset: u64,
prev_error: Option<Box<Self>>,
},
Forked {
offset: u64,
},
Decode {
offset: u64,
source: DecodeError,
},
Checksum {
offset: u64,
source: ChecksumMismatch,
},
Io(Error),
}Expand description
Error yielded by public commitlog iterators.
Variants
OutOfOrder
Fields
Forked
The log is considered forked iff a commit with the same min_tx_offset
but a different crc32 than the previous commit is encountered.
This may happen in rare circumstances where a write was considered
failed (e.g. due to a failed fsync(2)), when it was actually successful.
Decode
Checksum
Io(Error)